@@ -32,14 +32,16 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_NODE_H_
-#define _D_DHT_NODE_H_
+#ifndef D_DHT_NODE_H
+#define D_DHT_NODE_H
 
 #include "common.h"
+
+#include <string>
+
 #include "SharedHandle.h"
 #include "DHTConstants.h"
 #include "TimerA2.h"
-#include <string>
 
 namespace aria2 {
 
@@ -52,19 +54,21 @@ private:
   uint16_t port_;
 
   // in milli sec
-  unsigned int rtt_;
+  int rtt_;
 
-  unsigned int condition_;
+  int condition_;
 
   Timer lastContact_;
 public:
   DHTNode();
-  
+
   /**
    * id must be 20 bytes length
    */
   DHTNode(const unsigned char* id);
 
+  ~DHTNode();
+
   void generateID();
 
   const unsigned char* getID() const
@@ -72,7 +76,7 @@ public:
     return id_;
   }
 
-  void updateRTT(unsigned int millisec)
+  void updateRTT(int millisec)
   {
     rtt_ = millisec;
   }
@@ -82,10 +86,7 @@ public:
     return ipaddr_;
   }
 
-  void setIPAddress(const std::string& ipaddr)
-  {
-    ipaddr_ = ipaddr;
-  }
+  void setIPAddress(const std::string& ipaddr);
 
   void setID(const unsigned char* id);
 
@@ -122,4 +123,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DHT_NODE_H_
+#endif // D_DHT_NODE_H
