@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_MULTI_FILE_ALLOCATION_ITERATOR_H_
-#define _D_MULTI_FILE_ALLOCATION_ITERATOR_H_
+#ifndef D_MULTI_FILE_ALLOCATION_ITERATOR_H
+#define D_MULTI_FILE_ALLOCATION_ITERATOR_H
 
 #include "FileAllocationIterator.h"
 #include <deque>
@@ -49,19 +49,18 @@ private:
   MultiDiskAdaptor* diskAdaptor_;
   std::deque<SharedHandle<DiskWriterEntry> > entries_;
   SharedHandle<FileAllocationIterator> fileAllocationIterator_;
-  off_t offset_;
 public:
   MultiFileAllocationIterator(MultiDiskAdaptor* diskAdaptor);
 
   virtual ~MultiFileAllocationIterator();
 
   virtual void allocateChunk();
-  
+
   virtual bool finished();
 
-  virtual off_t getCurrentLength();
+  virtual int64_t getCurrentLength();
 
-  virtual uint64_t getTotalLength();
+  virtual int64_t getTotalLength();
 
   const std::deque<SharedHandle<DiskWriterEntry> >&
   getDiskWriterEntries() const;
@@ -69,4 +68,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_MULTI_FILE_ALLOCATION_ITERATOR_H_
+#endif // D_MULTI_FILE_ALLOCATION_ITERATOR_H
